@@ -16,19 +16,14 @@ logging.basicConfig(filename='hw.log', force=True, encoding='utf-8', level=loggi
 @click.option(
     "--sources",
     "-s",
-    default=["fruits"],
+    default=["fruit_sales"],
     multiple=True,
     help="specify the sources(s) for the stream(s), with each source preceded by a -s",
 )
 def main(sources: str) -> None:
 
-    logging.info('server started')
-
-    
     print()
-    time.sleep(0.2)
-    print(Fore.BLUE + Style.BRIGHT + "Headwaters:" + Style.NORMAL+ " Simple Stream Sources" + Style.RESET_ALL)
-    time.sleep(0.3)
+    print(Style.BRIGHT  + "Headwaters:" + Style.NORMAL+ " Simple Stream Sources" + Style.RESET_ALL)
     print()
     server.run(sources)
 
