@@ -7,9 +7,6 @@ import uuid
 from datetime import datetime
 from copy import deepcopy
 
-from numpy import source
-from pyparsing import original_text_for
-
 
 class Source:
 
